aboutsummaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
-rw-r--r--src/pbkdf/pbkdf2/pbkdf2.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/pbkdf/pbkdf2/pbkdf2.h b/src/pbkdf/pbkdf2/pbkdf2.h
index 2b25a7b1d..8b50b4a67 100644
--- a/src/pbkdf/pbkdf2/pbkdf2.h
+++ b/src/pbkdf/pbkdf2/pbkdf2.h
@@ -36,9 +36,9 @@ class BOTAN_DLL PKCS5_PBKDF2 : public PBKDF
/**
* Create a PKCS #5 instance using the specified message auth code
* @param mac the MAC to use
*/
- PKCS5_PBKDF2(MessageAuthenticationCode* m) : mac(m) {}
+ PKCS5_PBKDF2(MessageAuthenticationCode* mac_fn) : mac(mac_fn) {}
/**
* Destructor
@@ -36,9 +36,9 @@ class BOTAN_DLL PKCS5_PBKDF2 : public PBKDF
/**
* Create a PKCS #5 instance using the specified message auth code
- * @param mac the MAC to use
+ * @param mac_fn the MAC to use
*/